<?php
/**
 * Mirasvit
 *
 * This source file is subject to the Mirasvit Software License, which is available at https://mirasvit.com/license/.
 * Do not edit or add to this file if you wish to upgrade the to newer versions in the future.
 * If you wish to customize this module for your needs.
 * Please refer to http://www.magentocommerce.com for more information.
 *
 * @category  Mirasvit
 * @package   mirasvit/module-email
 * @version   2.5.7
 * @copyright Copyright (C) 2023 Mirasvit (https://mirasvit.com/)
 */


declare(strict_types=1);

/**
 * Created by PhpStorm.
 * User: vav
 * Date: 20.03.17
 * Time: 18:07
 */

namespace Mirasvit\Email\Controller\Adminhtml\Event;

use Magento\Backend\App\Action;
use Magento\Framework\Controller\ResultFactory;
use Magento\Ui\Component\MassAction\Filter;
use Mirasvit\Event\Api\Repository\EventRepositoryInterface;

class MassDelete extends Action
{
    private $filter;

    private $eventRepository;

    public function __construct(
        Filter                   $filter,
        EventRepositoryInterface $eventRepository,
        Action\Context           $context
    ) {
        $this->filter          = $filter;
        $this->eventRepository = $eventRepository;

        parent::__construct($context);
    }

    /**
     * @inheritDoc
     */
    public function execute()
    {
        $ids = $this->filter->getCollection($this->eventRepository->getCollection())->getAllIds();

        if (!is_array($ids)) {
            $this->messageManager->addErrorMessage((string)__('Please select event(s)'));
        } else {
            try {
                foreach ($ids as $eventId) {
                    $event = $this->eventRepository->get($eventId);
                    if ($event) {
                        $this->eventRepository->delete($event);
                    }
                }

                $this->messageManager->addSuccessMessage(
                    (string)__('Total of %1 record(s) were deleted', count($ids))
                );
            } catch (\Exception $e) {
                $this->messageManager->addErrorMessage($e->getMessage());
            }
        }

        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);

        return $resultRedirect->setPath('*/*/');
    }
}
